# Ejerecicio Final
 
##Metodosget
 
###1. get_data(path)
Lee un fichero csv desde path y lo devuelve en un pandas dataframe
 
###2. Método get_grupos_pokemon(path)
Devuelve los grupos dentro del fichero csv

###3. get_altura_media_grupo(path,type)
Devuelve la altura media por tipo de pokemon

###4. get_peso_media_grupo(path,type)
Devuelve el peso medio por tipo de pokemon